<?php


// Theme-Setup
add_action( 'after_setup_theme', 'ilisa_theme_setup' );

function ilisa_theme_setup() {

//Set the content width based on the theme's design and stylesheet.
	if ( !isset( $content_width ) )
		$content_width = 900;

// This theme supports automatic feed links 
	add_theme_support( 'automatic-feed-links' );

// This theme supports post thumbnails
	add_theme_support( 'post-thumbnails' );	

// This theme uses wp_nav_menu() in one location
	register_nav_menus( array(
		'main-menu' => __( 'Primary Navigation', 'ilisa' ),
	) );

// Register widgetized area and update sidebar with default widgets
	add_action( 'widgets_init', 'ilisa_widgets_init' );

// Load up the theme options page
	require ( get_template_directory() . '/includes/theme-options.php' );
	
// Used to style the TinyMCE editor
	add_editor_style( 'editor-style.css');

// Make theme available for translation, Translations can be filed in the /languages/ directory
	load_theme_textdomain('ilisa', get_template_directory() . '/languages');	
	
// This theme supports custom background (with backwards compatibility)
	$args = array(
		'default-color' => 'FFFFFF',
	);

	$args = apply_filters( 'ilisa_custom_background_args', $args );

	if ( function_exists( 'wp_get_theme' ) ) {
		add_theme_support( 'custom-background', $args );
	}
}

 function ilisa_head_script(){
 ?>
	 <!--[if lt IE 9]>
		 <script src="//html5shiv.googlecode.com/svn/trunk/html5.js"></script>
	 <![endif]-->
 <?php
 }
 add_action( 'wp_head', 'ilisa_head_script' );

function favicon_link() {
	$options = get_option('ilisa_theme_options');
	
    echo '<link rel="shortcut icon" type="image/x-icon" href="'.esc_url( $options['custom_favicon'] ).' "/>' . "\n";
}
add_action('wp_head', 'favicon_link');


// Load CSS 
function ilisa_load_styles() {
	wp_enqueue_style( 'style', get_stylesheet_uri() );
}
add_action( 'wp_enqueue_scripts', 'ilisa_load_styles' );
 


function ilisa_filter_wp_title( $title ) {
    // Get the Site Name
    $site_name = get_bloginfo( 'name' );
    // Prepend it to the default output
    $filtered_title = $site_name ." ". $title;
    // Return the modified title
    return $filtered_title;
}

// Hook into 'wp_title'
add_filter( 'wp_title', 'ilisa_filter_wp_title' );

function ilisa_custom_blogname_rss($val, $show) {
	if( 'name' == $show )
		$out = 'Feed: ';
	else
		$out = $val;
	return $out;
}
add_filter('bloginfo_rss','ilisa_custom_blogname_rss', 10, 2);

// Register widgetized area and update sidebar with default widgets
function ilisa_widgets_init() {
	register_sidebar( array (
		'name' => __( 'Sidebar', 'ilisa' ),
		'id' => 'sidebar',
        'description' => __('The widget area on the sidebar', 'ilisa'),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}

// Remove predefined gallery styles
add_filter( 'use_default_gallery_style', '__return_false' );


//Comments
function ilisa_enqueue_comment_reply() {
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) { 
		wp_enqueue_script( 'comment-reply' ); 
	}
}
add_action( 'wp_enqueue_scripts', 'ilisa_enqueue_comment_reply' );


// This theme supports custom header
require( get_template_directory() . '/includes/custom-header.php' );


 // Adds a class of .no-sidebar when there are no widgets in the right sidebar
function ilisa_body_classes( $classes ) {
	if ( ! is_active_sidebar( 'sidebar' ) ) {
    	$classes[] = 'no-sidebar';
    }
	return $classes;
 }
 add_filter( 'body_class', 'ilisa_body_classes' );

if ( ! function_exists( 'ilisa_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Ilisa 1.0
 */
function ilisa_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'ilisa' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'ilisa' ), ' ' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer>
				<div class="comment-author vcard">
					<?php echo get_avatar( $comment, 40 ); ?>
                    <div class="comment-meta-container">
					<?php printf( __( '%s <span class="says">says:</span>', 'ilisa' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
				<div class="comment-meta commentmetadata">
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>"><time datetime="<?php comment_time( 'c' ); ?>">
					<?php
						/* translators: 1: date, 2: time */
						printf( __( '%1$s at %2$s', 'ilisa' ), get_comment_date(), get_comment_time() ); ?>
					</time></a>
					<?php edit_comment_link( __( '(Edit)', 'ilisa' ), ' ' );
					?>
				</div><!-- .comment-meta .commentmetadata -->
                </div><!-- .comment-meta-container -->
				</div><!-- .comment-author .vcard -->
                
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em><?php _e( 'Your comment is awaiting moderation.', 'ilisa' ); ?></em>
					<br />
				<?php endif; ?>


			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
endif; // ends check for ilisa_comment()

 // Enable shortcodes in widget areas
add_filter( 'widget_text', 'do_shortcode' );

// Replace WP autop formatting
if (!function_exists( "ilisa_remove_wpautop")) {
	function ilisa_remove_wpautop($content) { 
		$content = do_shortcode( shortcode_unautop( $content ) ); 
		$content = preg_replace( '#^<\/p>|^<br \/>|<p>$#', '', $content);
		return $content;
	}
}


// Columns Shortcodes
// Don't forget to add "_last" behind the shortcode if it is the last column.

// Two Columns

function ilisa_shortcode_one_half( $atts, $content = null ) {
   return '<div class="one_half">' . ilisa_remove_wpautop($content) . '</div>';
}
add_shortcode( 'one_half', 'ilisa_shortcode_one_half' );

function ilisa_shortcode_one_half_last( $atts, $content = null ) {
   return '<div class="one_half last">' . ilisa_remove_wpautop($content) . '</div>';
}
add_shortcode( 'one_half_last', 'ilisa_shortcode_one_half_last' );

// Three Columns
function ilisa_shortcode_one_third($atts, $content = null) {
   return '<div class="one_third">' . ilisa_remove_wpautop($content) . '</div>';
}
add_shortcode( 'one_third', 'ilisa_shortcode_one_third' );

function ilisa_shortcode_one_third_last($atts, $content = null) {
   return '<div class="one_third last">' . ilisa_remove_wpautop($content) . '</div>';
}
add_shortcode( 'one_third_last', 'ilisa_shortcode_one_third_last' );

function ilisa_shortcode_two_third($atts, $content = null) {
   return '<div class="two_third">' . ilisa_remove_wpautop($content) . '</div>';
}
add_shortcode( 'two_third', 'ilisa_shortcode_two_third' );

function ilisa_shortcode_two_third_last($atts, $content = null) {
   return '<div class="two_third last">' . ilisa_remove_wpautop($content) . '</div>';
}
add_shortcode( 'two_third_last', 'ilisa_shortcode_two_third_last' );


// Four Columns
function ilisa_shortcode_one_fourth($atts, $content = null) {
   return '<div class="one_fourth">' . ilisa_remove_wpautop($content) . '</div>';
}
add_shortcode( 'one_fourth', 'ilisa_shortcode_one_fourth' );

function ilisa_shortcode_one_fourth_last($atts, $content = null) {
   return '<div class="one_fourth last">' . ilisa_remove_wpautop($content) . '</div>';
}
add_shortcode( 'one_fourth_last', 'ilisa_shortcode_one_fourth_last' );

function ilisa_shortcode_three_fourth( $atts, $content = null ) {
    return '<div class="three_fourth">' . ilisa_remove_wpautop($content) . '</div>';
}
add_shortcode( 'three_fourth', 'ilisa_shortcode_three_fourth' );

function ilisa_shortcode_three_fourth_last( $atts, $content = null ) {
    return '<div class="three_fourth last">' . ilisa_remove_wpautop($content) . '</div>';
}
add_shortcode( 'three_fourth_last', 'ilisa_shortcode_three_fourth_last' );



// Divide Text Shortcode
function ilisa_shortcode_divider($atts, $content = null) {
   return '<div class="divider"></div>';
}
add_shortcode( 'divider', 'ilisa_shortcode_divider' );

//Text Highlight and Info Boxes Shortcodes
function ilisa_shortcode_highlight($atts, $content = null) {
   return '<span class="highlight">' . do_shortcode( ilisa_remove_wpautop($content) ) . '</span>';
}
add_shortcode( 'highlight', 'ilisa_shortcode_highlight' );

function ilisa_shortcode_white_box($atts, $content = null) {
   return '<div class="white-box">' . do_shortcode( ilisa_remove_wpautop($content) ) . '</div>';
}
add_shortcode( 'white_box', 'ilisa_shortcode_white_box' );

function ilisa_shortcode_blue_box($atts, $content = null) {
   return '<div class="blue-box">' . do_shortcode( ilisa_remove_wpautop($content) ) . '</div>';
}
add_shortcode( 'blue_box', 'ilisa_shortcode_blue_box' );

function ilisa_shortcode_yellow_box($atts, $content = null) {
   return '<div class="yellow-box">' . do_shortcode( ilisa_remove_wpautop($content) ) . '</div>';
}
add_shortcode( 'yellow_box', 'ilisa_shortcode_yellow_box' );

function ilisa_shortcode_orange_box($atts, $content = null) {
   return '<div class="orange-box">' . do_shortcode( ilisa_remove_wpautop($content) ) . '</div>';
}
add_shortcode( 'orange_box', 'ilisa_shortcode_orange_box' );

function ilisa_shortcode_red_box($atts, $content = null) {
   return '<div class="red-box">' . do_shortcode( ilisa_remove_wpautop($content) ) . '</div>';
}
add_shortcode( 'red_box', 'ilisa_shortcode_red_box' );

function ilisa_shortcode_pink_box($atts, $content = null) {
   return '<div class="pink-box">' . do_shortcode( ilisa_remove_wpautop($content) ) . '</div>';
}
add_shortcode( 'pink_box', 'ilisa_shortcode_pink_box' );

function ilisa_shortcode_green_box($atts, $content = null) {
   return '<div class="green-box">' . do_shortcode( ilisa_remove_wpautop($content) ) . '</div>';
}
add_shortcode( 'green_box', 'ilisa_shortcode_green_box' );

function ilisa_shortcode_grey_box($atts, $content = null) {
   return '<div class="grey-box">' . do_shortcode( ilisa_remove_wpautop($content) ) . '</div>';
}
add_shortcode( 'grey_box', 'ilisa_shortcode_grey_box' );

function ilisa_shortcode_brown_box($atts, $content = null) {
   return '<div class="brown-box">' . do_shortcode( ilisa_remove_wpautop($content) ) . '</div>';
}
add_shortcode( 'brown_box', 'ilisa_shortcode_brown_box' );
