<?php

/**
* Setup the WordPress core custom header feature.
*
* @uses ilisa_admin_header_style()
* @uses ilisa_admin_header_image()
*
*/

function ilisa_custom_header_setup() {
	$args = array(
	'default-image' => '',
	'width' => 360,
	'height' => 180,
	'header-text'   => false,	
	'flex-height' => true,
	'flex-width' => true,
	'admin-head-callback' => 'ilisa_admin_header_style',
	'admin-preview-callback' => 'ilisa_admin_header_image',
);

	$args = apply_filters( 'ilisa_custom_header_args', $args );

	if ( function_exists( 'wp_get_theme' ) ) {
		add_theme_support( 'custom-header', $args );
	} 
}

add_action( 'after_setup_theme', 'ilisa_custom_header_setup' );

/**
* Shiv for get_custom_header().
*
*/

if ( ! function_exists( 'get_custom_header' ) ) {
	function get_custom_header() {
		return (object) array(
			'url' => get_header_image(),
			'width' => HEADER_IMAGE_WIDTH,
			'height' => HEADER_IMAGE_HEIGHT,
		);
	}
}


if ( ! function_exists( 'ilisa_admin_header_style' ) ) :

/**
* Styles the header image displayed on the Appearance > Header admin panel.
* @see ilisa_custom_header_setup().
*/

function ilisa_admin_header_style() {
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		border: none;
	}
	#headimg h1,
	#desc {
	}
	#headimg h1 {font-size:4em;
	}
	#headimg h1 a { text-decoration:none;
	}
	#desc {
	}
	#headimg img {
	}
	</style>

<?php
}
endif; // ilisa_admin_header_style

if ( ! function_exists( 'ilisa_admin_header_image' ) ) :
/**
* Custom header image markup displayed on the Appearance > Header admin panel.
* @see ilisa_custom_header_setup().
*/

function ilisa_admin_header_image() { ?>
	<div id="headimg">
		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<img src="<?php echo esc_url( $header_image ); ?>" alt="" /><?php
        else: 
		$options = ilisa_get_theme_options();
		if (isset($options)):
			$style = ' style="color:' . esc_html( $options['custom_color'] ) . ';"';
		else:
			$default_options = ilisa_get_default_theme_options();			
			$style = ' style="color:' . esc_html( $default_options['custom_color'] ) . ';"';
		endif;
		$style2 = ' style="color:#333333;"';
			
?>
	<h1><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
	<div id="desc"<?php echo $style2; ?>><?php bloginfo( 'description' ); ?></div>
       
		<?php endif; ?>
	</div>
<?php }


endif; // ilisa_admin_header_image